ipsec whack --impair suppress_retransmits
# expected to fail
ipsec auto --up westnet-eastnet-ipv4-psk-ppk
echo done
